aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--sway/input/cursor.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/sway/input/cursor.c b/sway/input/cursor.c
index 5eb44412..35683f06 100644
--- a/sway/input/cursor.c
+++ b/sway/input/cursor.c
@@ -83,8 +83,8 @@ struct sway_node *node_at_coords(
return NULL;
}
struct sway_output *output = wlr_output->data;
- if (!output) {
- // output is being destroyed
+ if (!output || !output->configured) {
+ // output is being destroyed or is being configured
return NULL;
}
double ox = lx, oy = ly;